@@ -1037,9 +1037,10 @@ class FOFDataManagerLite:
         if fof_nav is None:
             fof_nav = fof_nav_public
         else:
+            existed_fof_id_list = fof_nav.fof_id.unique()
             fof_nav = fof_nav.drop(columns=['update_time', 'create_time', 'is_deleted'])
             if fof_nav_public is not None:
-                fof_nav = fof_nav.combine_first(fof_nav_public)
+                fof_nav = fof_nav.combine_first(fof_nav_public[~fof_nav_public.fof_id.isin(existed_fof_id_list)])
         if fof_nav is not None:
             if ref_index_id:
                 index_price = BasicDataApi().get_index_price(index_list=[ref_index_id])
@@ -1057,9 +1058,10 @@ class FOFDataManagerLite:
 
     @staticmethod
     def get_fof_nav_public(manager_id: str, fof_id: Tuple[str] = ()) -> Optional[pd.DataFrame]:
-        fof_nav = DerivedDataApi().get_fof_nav_public(manager_id, fof_id)
+        fof_nav = DerivedDataApi().get_fof_nav_public(fof_id)
         if fof_nav is None:
             return
+        fof_nav['manager_id'] = manager_id
         return fof_nav.drop(columns=['update_time', 'create_time', 'is_deleted'])
 
     @staticmethod
