@@ -12,46 +12,43 @@ import pdfplumber
 
 from ...util.mail_retriever import MailAttachmentRetriever, IMAP_SPType, UID_FILE_NAME
 from ...util.wechat_bot import WechatBot
-from ..wrapper.mysql import BasicDatabaseConnector
-from ..view.basic_models import HedgeFundNAV
-from ..api.basic import BasicDataApi
+from ..wrapper.mysql import DerivedDatabaseConnector
+from ..view.derived_models import FOFUnconfirmedNav
+from ..api.derived import DerivedDataApi
 
 
 class HedgeFundNAVReader:
 
     COLUMNS_DICT = {
-        '基金代码': 'fund_id',
-        '产品代码': 'fund_id',
-        '基金名称': 'fund_name',
-        '产品名称': 'fund_name',
-        '基金份额净值': 'net_asset_value',
-        '单位净值': 'net_asset_value',
-        '计提前单位净值': 'net_asset_value',
-        '实际净值': 'net_asset_value',
-        '基金份额累计净值': 'acc_unit_value',
-        '累计单位净值': 'acc_unit_value',
-        '累计净值': 'acc_unit_value',
-        '虚拟后净值': 'v_net_value',
-        '虚拟净值': 'v_net_value',
-        '计提后单位净值': 'v_net_value',
-        '虚拟计提净值': 'v_net_value',
-        '虚拟后单位净值': 'v_net_value',
-        '复权累计净值': 'adjusted_net_value',
-        '复权净值': 'adjusted_net_value',
-        '净值(分红再投)': 'adjusted_net_value',
+        '基金代码': 'fof_id',
+        '产品代码': 'fof_id',
+        '基金名称': 'fof_name',
+        '产品名称': 'fof_name',
+        '基金份额净值': 'nav',
+        '单位净值': 'nav',
+        '计提前单位净值': 'nav',
+        '实际净值': 'nav',
+        '基金份额累计净值': 'acc_net_value',
+        '累计单位净值': 'acc_net_value',
+        '累计净值': 'acc_net_value',
+        '虚拟后净值': 'v_nav',
+        '虚拟净值': 'v_nav',
+        '计提后单位净值': 'v_nav',
+        '虚拟计提净值': 'v_nav',
+        '虚拟后单位净值': 'v_nav',
         '日期': 'datetime',
         '净值日期': 'datetime',
         '业务日期': 'datetime',
-        '计算日期': 'calc_date',
     }
 
-    def __init__(self, read_dir: str, user_name: str, password: str):
+    def __init__(self, manager_id: str, read_dir: str, user_name: str, password: str):
         pd.set_option('display.max_rows', None)
         pd.set_option('display.max_columns', None)
 
         self._read_dir = read_dir
         assert os.path.isdir(self._read_dir), f'arg dump_dir should be a directory (now){self._read_dir}'
 
+        self._manager_id = manager_id
         self._user_name = user_name
         self._password = password
         self._wechat_bot = WechatBot()
@@ -85,7 +82,7 @@ class HedgeFundNAVReader:
     @staticmethod
     def _read_for_TianYanGuangQuan(file_path: str) -> pd.DataFrame:
         df = pd.read_excel(file_path, skipfooter=1)
-        df = df.loc[:, ['基金名称', '基金代码', '净值日期', '计算日期', '单位净值', '累计单位净值', '虚拟净值']]
+        df = df.loc[:, ['基金名称', '基金代码', '净值日期', '单位净值', '累计单位净值', '虚拟净值']]
         df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
         return df
 
@@ -127,7 +124,7 @@ class HedgeFundNAVReader:
         assert (len(dates_data) >= 2) and (dates_data[0] == '日期'), 'invalid format from TaiChuangXiShuoCTA'
         df = df.loc[['单位净值', '累计单位净值'], :].T
         df['datetime'] = pd.to_datetime(str(dates_data[1]), infer_datetime_format=True).date()
-        df['fund_id'] = 'SNH765'
+        df['fof_id'] = 'SNH765'
         df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
         return df
 
@@ -192,9 +189,9 @@ class HedgeFundNAVReader:
         df = pd.Series(data[1], index=data[0]).to_frame().T
         df = df[['单位净值']]
         df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
-        df['fund_id'] = 'SJJ077'
+        df['fof_id'] = 'SJJ077'
         df['datetime'] = the_date
-        df['acc_unit_value'] = df['net_asset_value']
+        df['acc_net_value'] = df['nav']
         return df
 
     @staticmethod
@@ -284,8 +281,8 @@ class HedgeFundNAVReader:
                 continue
 
             try:
-                df = df.drop(columns=['fund_name'], errors='ignore')
-                df['insert_time'] = datetime.datetime.now()
+                df = df.drop(columns=['fof_name'], errors='ignore')
+                df['manager_id'] = self._manager_id
                 df = self._dump_to_db(df)
                 if df is not None:
                     df_list.append(df)
@@ -301,7 +298,7 @@ class HedgeFundNAVReader:
 
         if df_list:
             try:
-                whole_df = pd.concat(df_list).set_index('fund_id')
+                whole_df = pd.concat(df_list).set_index('fof_id')
                 print(whole_df)
             except Exception as e:
                 self._notify_error_event(f'{e} (concat)')
@@ -322,8 +319,8 @@ class HedgeFundNAVReader:
     def _dump_to_db(self, df: pd.DataFrame):
         def _check_after_merged(x: pd.Series, now_df: pd.DataFrame):
             try:
-                now_data = now_df[(now_df.fund_id == x.fund_id) & (now_df.datetime == x.datetime)]
-                if now_data[['net_asset_value', 'acc_unit_value', 'v_net_value']].iloc[0].astype('float64').equals(x[['net_asset_value', 'acc_unit_value', 'v_net_value']].astype('float64')):
+                now_data = now_df[(now_df.fof_id == x.fof_id) & (now_df.datetime == x.datetime)]
+                if now_data[['nav', 'acc_net_value', 'v_nav']].iloc[0].astype('float64').equals(x[['nav', 'acc_net_value', 'v_nav']].astype('float64')):
                     return pd.Series(dtype='object')
                 else:
                     return x
@@ -331,14 +328,14 @@ class HedgeFundNAVReader:
                 return x
 
         assert df.datetime.nunique() == 1, 'should have single datetime'
-        now_df = BasicDataApi().get_hedge_fund_nav(fund_id_list=list(df.fund_id.unique()))
+        now_df = DerivedDataApi().get_fof_nav_unconfirmed(manager_id=self._manager_id, fof_id_list=list(df.fof_id.unique()))
         if now_df is not None and not now_df.empty:
-            # 同产品同日期的净值如果已经存在了且没有变化，就不写DB了
-            now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted', 'change_rate']).sort_values(by=['fund_id', 'datetime']).drop_duplicates(subset=['fund_id', 'datetime'], keep='last')
-            now_df = now_df.astype({'net_asset_value': 'float64', 'acc_unit_value': 'float64', 'v_net_value': 'float64'})
+            # 同产品同日期的净值如果已经存在了且没有变化 就不写DB了
+            now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted']).sort_values(by=['manager_id', 'fof_id', 'datetime']).drop_duplicates(subset=['manager_id', 'fof_id', 'datetime'], keep='last')
+            now_df = now_df.astype({'nav': 'float64', 'acc_net_value': 'float64', 'v_nav': 'float64'})
             df = df.reindex(columns=now_df.columns).astype(now_df.dtypes.to_dict())
-            df = df.merge(now_df, how='left', on=['fund_id', 'datetime', 'net_asset_value', 'acc_unit_value', 'v_net_value'], indicator=True, validate='one_to_one')
-            df = df[df._merge == 'left_only'].drop(columns=['_merge', 'insert_time_y', 'calc_date_y', 'adjusted_net_value_y', 'ta_factor_y']).rename(columns={'insert_time_x': 'insert_time', 'calc_date_x': 'calc_date', 'adjusted_net_value_x': 'adjusted_net_value', 'ta_factor_x': 'ta_factor'})
+            df = df.merge(now_df, how='left', on=['manager_id', 'fof_id', 'datetime', 'nav', 'acc_net_value', 'v_nav'], indicator=True, validate='one_to_one')
+            df = df[df._merge == 'left_only'].drop(columns=['_merge'])
             if df.empty:
                 return
             # FIXME 没想到特别好的方法 遍历每一行再check一下
@@ -346,17 +343,16 @@ class HedgeFundNAVReader:
             df = df.apply(_check_after_merged, axis=1, now_df=now_df)
             if df.empty:
                 return
-            df['insert_time'] = df.insert_time.map(lambda x: x.to_pydatetime())
-            df = df.set_index(['fund_id', 'datetime'])
+            df = df.set_index(['manager_id', 'fof_id', 'datetime'])
             print(df)
-            df.update(now_df.set_index(['fund_id', 'datetime']), overwrite=False)
+            df.update(now_df.set_index(['manager_id', 'fof_id', 'datetime']), overwrite=False)
             df = df.reset_index()
             df['datetime'] = df.datetime.map(lambda x: x.date())
             print(df)
             # 先删后添
-            for fund_id in df.fund_id.unique():
-                BasicDataApi().delete_hedge_fund_nav(fund_id_to_delete=fund_id, date_list=df[df.fund_id == fund_id].datetime.to_list())
-        df.to_sql(HedgeFundNAV.__table__.name, BasicDatabaseConnector().get_engine(), index=False, if_exists='append')
+            for fof_id in df.fof_id.unique():
+                DerivedDataApi().delete_fof_nav_unconfirmed(manager_id=self._manager_id, fof_id=fof_id, date_list=df[df.fof_id == fof_id].datetime.to_list())
+        df.to_sql(FOFUnconfirmedNav.__table__.name, DerivedDatabaseConnector().get_engine(), index=False, if_exists='append')
         return df
 
 
@@ -369,5 +365,7 @@ if __name__ == '__main__':
         import sys
         sys.exit(f'can not found enough params in env (e){e}')
 
-    hf_nav_r = HedgeFundNAVReader(email_data_dir, user_name, password)
+    MANAGER_ID = 'py1'
+
+    hf_nav_r = HedgeFundNAVReader(MANAGER_ID, email_data_dir, user_name, password)
     hf_nav_r.read_navs_and_dump_to_db()
