@@ -892,15 +892,15 @@ class FOFInfo(FOFBase):
     manager_id = Column(VARCHAR(32), primary_key=True)  # 管理端ID
     datetime = Column(CHAR(16))  # 数据日期（以支持更新操作）
     fof_name = Column(TEXT, nullable=False)  # 产品名称
-    desc_name = Column(CHAR(15))  # 简称
+    desc_name = Column(CHAR(31))  # 简称
     admin = Column(TEXT)  # 管理人
     established_date = Column(DATE, nullable=False)  # 成立日期
     fof_status = Column(CHAR(16))  # 申赎状态等
-    subscription_fee = Column(DOUBLE(asdecimal=False), nullable=False)  # 认购费率
+    subscription_fee = Column(DOUBLE(asdecimal=False))  # 认购费率
     redemption_fee = Column(TEXT)  # 赎回费率
-    management_fee = Column(DOUBLE(asdecimal=False), nullable=False)  # 管理费率
-    custodian_fee = Column(DOUBLE(asdecimal=False), nullable=False)  # 托管费率
-    administrative_fee = Column(DOUBLE(asdecimal=False), nullable=False)  # 行政管理费率
+    management_fee = Column(DOUBLE(asdecimal=False))  # 管理费率
+    custodian_fee = Column(DOUBLE(asdecimal=False))  # 托管费率
+    administrative_fee = Column(DOUBLE(asdecimal=False))  # 行政管理费率
     lock_up_period = Column(TEXT)  # 锁定期
     incentive_fee_mode = Column(VARCHAR(31))  # 业绩报酬计提方法
     incentive_fee_type = Column(VARCHAR(31))  # 业绩报酬计提类型
@@ -1211,3 +1211,25 @@ class FOFAssertCorrect(FOFBase):
     date = Column(DATE)                                             # 日期
     amount = Column(DOUBLE(asdecimal=False))                        # 金额
     remark = Column(VARCHAR(255))                                   # 备注
+
+
+class EMailParserInfo(FOFBase):
+    '''parser信息表'''
+
+    __tablename__ = 'email_parser_info'
+
+    manager_id = Column(CHAR(32), primary_key=True)  # 管理端ID
+    p_id = Column(CHAR(16), primary_key=True)  # parser ID
+    p_desc = Column(TEXT)                      # parser 描述
+    p_type = Column(Integer)                   # parser 类型
+    is_valid = Column(BOOLEAN)                 # parser 是否生效
+
+
+class EMailParserCode(FOFBase):
+    '''parser代码表'''
+
+    __tablename__ = 'email_parser_code'
+
+    manager_id = Column(CHAR(32), primary_key=True)  # 管理端ID
+    p_id = Column(CHAR(16), primary_key=True)        # parser ID
+    p_code = Column(TEXT)                            # parser 代码
